Forensify
alexgreensh/repo-forensics
Cross-agent self-inspection of your AI-agent stack. An agent skill from alexgreensh/repo-forensics.
Tile two-dimensional torch.gather(dim=1) kernels for Triton-Ascend so the logical grid stays near the physical vector-core count while each program handles multiple batch rows and loops over K.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tile-triton-ascend-gather --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/tile-triton-ascend-gather .claude/skills/tile-triton-ascend-gather && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "tile-triton-ascend-gather" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gather into .claude/skills/tile-triton-ascend-gather/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tile-triton-ascend-gather", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gatherType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tile-triton-ascend-gather --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/tile-triton-ascend-gather .agents/skills/tile-triton-ascend-gather && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "tile-triton-ascend-gather" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gather into .agents/skills/tile-triton-ascend-gather/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tile-triton-ascend-gather", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tile-triton-ascend-gather --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/tile-triton-ascend-gather .cursor/skills/tile-triton-ascend-gather && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "tile-triton-ascend-gather" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gather into .cursor/skills/tile-triton-ascend-gather/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tile-triton-ascend-gather", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/tile-triton-ascend-gather--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tile-triton-ascend-gather --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/tile-triton-ascend-gather .gemini/skills/tile-triton-ascend-gather && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "tile-triton-ascend-gather" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gather into .gemini/skills/tile-triton-ascend-gather/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tile-triton-ascend-gather", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tile-triton-ascend-gatherInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/tile-triton-ascend-gather .github/skills/tile-triton-ascend-gather && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "tile-triton-ascend-gather" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gather into .github/skills/tile-triton-ascend-gather/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tile-triton-ascend-gather", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tile-triton-ascend-gather --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/tile-triton-ascend-gather .opencode/skills/tile-triton-ascend-gather && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "tile-triton-ascend-gather" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tile-triton-ascend-gather into .opencode/skills/tile-triton-ascend-gather/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tile-triton-ascend-gather", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
tile-triton-ascend-gatherTile two-dimensional torch.gather(dim=1) kernels for Triton-Ascend so the logical grid stays near the physical vector-core count while each program handles multiple batch rows and loops over K.
Tile Triton Ascend Gather is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Tile two-dimensional torch.gather(dim=1) kernels for Triton-Ascend so the logical grid stays near the physical vector-core count while each program handles multiple batch rows and loops over K. Use when an agent ports a GPU grid of B by ceil(K/BLOCKK), observes NPU launch or scheduling overhead, or needs stride-aware indexed row gathers.
Its SKILL.md is about 580 tokens, which your agent loads only when the skill is triggered. It is a single SKILL.md file with no bundled scripts.
It sits in Security, covering Threat modeling. The repository describes itself as: A toolkit for AI agents used for development on Triton-Ascend for Ascend NPU. The licence is Apache-2.0.
5 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Tile Triton Ascend Gather loads about 583 tokens when it runs. Until then it costs about 92 tokens; SKILL.md has 167 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 167 words, ~583 tokens.
.claude/skills/tile-triton-ascend-gather/SKILL.md (or your agent's skills folder).Compute out[b, k] = x[b, index[b, k]] without launching one logical program for every batch-row and K tile.
@triton.jit
def gather_dim1(x, indices, out, sx_b, sx_c, si_b, si_k, so_b, so_k,
B, C, K, BLOCK_B: tl.constexpr, BLOCK_K: tl.constexpr):
rows = tl.program_id(0) * BLOCK_B + tl.arange(0, BLOCK_B)
row_mask = rows < B
for k_start in tl.range(0, K, BLOCK_K):
ks = k_start + tl.arange(0, BLOCK_K)
tile_mask = row_mask[:, None] & (ks[None, :] < K)
index_offsets = rows[:, None] * si_b + ks[None, :] * si_k
cols = tl.load(indices + index_offsets, mask=tile_mask, other=0)
valid = tile_mask & (cols >= 0) & (cols < C)
values = tl.load(x + rows[:, None] * sx_b + cols * sx_c, mask=valid)
output_offsets = rows[:, None] * so_b + ks[None, :] * so_k
tl.store(out + output_offsets, values, mask=valid)Compare with torch.gather(x, dim=1, index=indices). Cover B smaller and larger than the core count, K tails, non-contiguous strides, repeated indices, and invalid-index rejection.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/tile-triton-ascend-gather of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Tile Triton Ascend Gather next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Tile Triton Ascend Gather this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~583 | Automated safety check: Pass | Apache-2.0 | |
| Forensifyalexgreensh/repo-forensics | 190 | — | ~2.5k | Automated safety check: Notes | Custom licence | |
| Create Rulecartography-cncf/cartography | 4.1k | — | ~3k | Automated safety check: Pass | Apache-2.0 | |
| Commit Security Scancodexstar69/bug-hunter | 520 | — | ~629 | Automated safety check: Pass | MIT | |
| Auditing Code For Vulnerabilitiestrilwu/secskills | 157 | — | ~3.2k | Automated safety check: Pass | MIT | |
| Threat Mitigation Mappingwshobson/agents | 40k | 8 repos | ~742 | Automated safety check: Pass | MIT |
alexgreensh/repo-forensics
Cross-agent self-inspection of your AI-agent stack. An agent skill from alexgreensh/repo-forensics.
cartography-cncf/cartography
Author a Cartography security rule (one or more Cypher Facts plus a Pydantic Finding output model) under cartography/rules/data/rules/.
codexstar69/bug-hunter
Scan code changes for security vulnerabilities using Bug Hunter-native artifacts and STRIDE context.
trilwu/secskills
Audit source code for exploitable vulnerabilities using threat-model-driven review, taint tracing, invariant checking, and variant analysis.
wshobson/agents
Match identified threats to preventive, detective and corrective controls across network, application, data, endpoint and process layers to plan remediation.
nordstjernen-web/northstar-browser
Audit browser-engine changes that process untrusted content or cross native-memory, origin, network, storage, extension, decoder, sandbox, or operating-system boundaries.
Krusty84/triton-ascend-agent-dev-kit
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
Krusty84/triton-ascend-agent-dev-kit
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Categories
Tile two-dimensional torch.gather(dim=1) kernels for Triton-Ascend so the logical grid stays near the physical vector-core count while each program handles multiple batch rows and loops over K. Tile Triton Ascend Gather is an agent skill from Krusty84/triton-ascend-agent-dev-kit.gather(dim=1) kernels for Triton-Ascend so the logical grid stays near the physical vector-core count while each program handles multiple batch rows and loops over K.
Tile Triton Ascend Gather fits situations like: an agent ports a GPU grid of B by ceil(K/BLOCKK); observes NPU launch; scheduling overhead; needs stride-aware indexed row gathers.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a claude-code`. Or copy the skill folder (skills/tile-triton-ascend-gather in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/tile-triton-ascend-gather in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a codex`. Or copy the skill folder (skills/tile-triton-ascend-gather in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/tile-triton-ascend-gather in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tile-triton-ascend-gather -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/tile-triton-ascend-gather, .gemini/skills/tile-triton-ascend-gather, .github/skills/tile-triton-ascend-gather and .opencode/skills/tile-triton-ascend-gather in your project.
SKILL.md names no scripts, command-line tools or credentials: Tile Triton Ascend Gather is instructions for the agent only. Our summary lists: Python 3.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Tile Triton Ascend Gather is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 583 tokens (SKILL.md is roughly 2.3k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Tile Triton Ascend Gather: Forensify (alexgreensh/repo-forensics, 190 stars), Create Rule (cartography-cncf/cartography, 4.1k stars), Commit Security Scan (codexstar69/bug-hunter, 520 stars) and Auditing Code For Vulnerabilities (trilwu/secskills, 157 stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.